==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-utf8/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* コマンドヘルプ,man,musahi GUI 共通メッセージ管理                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* コマンドのタイトル                                                         */
/* コマンドヘルプの最初の行に表示                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablのヘッダー変更"

/*----------------------------------------------------------------------------*/
/* パラメータ                                                                 */
/* コマンドヘルプの USAGE:として"キーワード XXXT"を表示 ex)-k キー項目名リスト*/
/* flagのオプションはコマンドヘルプのOPTIONS)として表示 ex)-z : 標準出力の圧縮*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "新しい項目名リスト"
#define FNMC "ここで指定した項目名リストに変更される"

/*-l*/
#define TITT "タイトル"
#define TITC "ここで指定したタイトルに変更される"

/*-c*/
#define COMT "コメント"
#define COMC "ここで指定したコメントに変更される"

/*-I*/
#define IMPT "インポートファイル名"
#define IMPC "ヘッダーをインポートし、そのヘッダーに変更する"

/*-S*/
#define SRTT "ソート情報消去"
#define SRTC "ヘッダーの項目情報のうち、ソート情報のみを消去する。"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* 要約                                                                       */
/* コマンドヘルプのSUMMARY:として表示する                                     */
/* HTMLヘルプやmanには、下のHELPDの上に結合する形で表示する                   */
/*----------------------------------------------------------------------------*/
#define HELPS "ヘッダー情報(項目名,タイトル,コメント)を変更する。"

/*----------------------------------------------------------------------------*/
/* 例                                                                         */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a 顧客,年月日,性別 -i dat.xt -o rsl.xt\n\
xtheader -l 顧客マスター -c 2002年01月01日時点 -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* 参照コマンド(必ずカンマで区切り、空白は用いない)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* 作者について                                                               */
/* コマンドヘルプには表示されない                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* バグレポート                                                               */
/* ここを登録すればコマンドヘルプのBUG REPORT:に表示される。                  */
/* 登録がなければ(#define HELPB "")何も表示しない。                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ホームページ                                                               */
/* ここを登録すればコマンドヘルプのINFORMATION:に表示される。                 */
/* 登録がなければ(#define HELPH "")何も表示しない。                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-utf8/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* コマンドヘルプ,man,musahi GUI 共通メッセージ管理                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* コマンドのタイトル                                                         */
/* コマンドヘルプの最初の行に表示                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablのヘッダー変更"

/*----------------------------------------------------------------------------*/
/* パラメータ                                                                 */
/* コマンドヘルプの USAGE:として"キーワード XXXT"を表示 ex)-k キー項目名リスト*/
/* flagのオプションはコマンドヘルプのOPTIONS)として表示 ex)-z : 標準出力の圧縮*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "新しい全項目名リスト"
#define FNMC "ここで指定した項目名リストに変更される"

/*-f*/
#define FLDT "部分的に変更する項目名リスト"
#define FLDC "部分的な項目名の変更を「旧項目名:新項目名」の型式で指定する"
#define FLDF NULL

/*-l*/
#define TITT "タイトル"
#define TITC "ここで指定したタイトルに変更される"

/*-c*/
#define COMT "コメント"
#define COMC "ここで指定したコメントに変更される"

/*-I*/
#define IMPT "インポートファイル名"
#define IMPC "ヘッダーをインポートし、そのヘッダーに変更する"

/*-S*/
#define SRTT "ソート情報消去"
#define SRTC "ヘッダーの項目情報のうち、ソート情報のみを消去する。"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* 要約                                                                       */
/* コマンドヘルプのSUMMARY:として表示する                                     */
/* HTMLヘルプやmanには、下のHELPDの上に結合する形で表示する                   */
/*----------------------------------------------------------------------------*/
#define HELPS "ヘッダー情報(項目名,タイトル,コメント)を変更する。"

/*----------------------------------------------------------------------------*/
/* 例                                                                         */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a 顧客,年月日,性別 -i dat.xt -o rsl.xt\n\
xtheader -l 顧客マスター -c 2002年01月01日時点 -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
xtheader -f 年月日:日付,性別:gender -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* 参照コマンド(必ずカンマで区切り、空白は用いない)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* 作者について                                                               */
/* コマンドヘルプには表示されない                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* バグレポート                                                               */
/* ここを登録すればコマンドヘルプのBUG REPORT:に表示される。                  */
/* 登録がなければ(#define HELPB "")何も表示しない。                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ホームページ                                                               */
/* ここを登録すればコマンドヘルプのINFORMATION:に表示される。                 */
/* 登録がなければ(#define HELPH "")何も表示しない。                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
